@@ -56,7 +56,7 @@ class SelectedMethodWgt(qt.QWidget):
         layout.setSpacing(0)
         layout.addWidget(self.MethodWidget)
 
-        icon = get_icon('cl-console-gui-%s'%self.method.replace("_","-"),
+        icon = get_icon('console-gui-%s'%self.method.replace("_","-"),
                         'calculate-%s'%self.method.replace("_","-"))
 
         self.setWindowIcon(icon)
