@@ -14,7 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from PySide import QtGui, QtCore
+from calculate.consolegui import qt
 
 DEBUG_LEVEL = 0
 
@@ -30,10 +30,10 @@ from calculate.core.client.function import switch, create_obj
 from calculate.lib.utils.colortext.converter import XmlConverter
 from calculate.lib.utils.colortext.output import SpanCssOutput
 from calculate.lib.utils.tools import imap_regexp
-from more import WorkPalette
+from more import WorkPalette, ParameterWindow, get_system_rgb
 
 from more import get_sid, ClientServiceThread, show_msg, TaskWidget, ErrorWgt,\
-                 ResultLayout, get_view_params
+                 ResultLayout, get_view_params, get_icon
 from more import LabelWordWrap as Label
 from SelectTable import SelectedTableWidget
 
@@ -42,19 +42,20 @@ class LabelWordWrap(Label):
         Label.__init__(self, name, parent, mono, margin_top)
         # set text selectable
         self.setTextInteractionFlags(self.textInteractionFlags() | \
-                                     QtCore.Qt.TextSelectableByMouse)
+                                     qt.Qt.TextSelectableByMouse)
 
-class PlusButton(QtGui.QPushButton):
+class PlusButton(qt.QPushButton):
     def __init__(self, parent, ClientObj, method, disable_method=None):
-        QtGui.QPushButton.__init__(self, parent)
-        try:
-            self.setIcon(QtGui.QIcon.fromTheme('list-add'))
-        except:
+        qt.QPushButton.__init__(self, parent)
+        icon = get_icon('list-add')
+        if not icon.isNull():
+            self.setIcon(icon)
+        else:
             self.setText('+')
         self._parent = parent
         self.ClientObj = ClientObj
         self.method = method
-        self.setFixedWidth(30)
+        self.setFixedSize(30, 30)
         if disable_method:
             self.clicked.connect(disable_method)
         self.clicked.connect(self.call_method)
@@ -81,12 +82,12 @@ class PlusButton(QtGui.QPushButton):
                     ' - ' + self.ClientObj.Name)
         self._parent._parent.main_frame_view(view, self.method)
 
-class MainFrameRes(QtGui.QWidget):
-    valSignal = QtCore.Signal()
+class MainFrameRes(qt.QWidget):
+    valSignal = qt.Signal()
     def __init__(self, parent, ClientObj, method_name, meth_result,
                  change_offset=False):
 #        super(MainFrameRes, self).__init__(self, parent)
-        QtGui.QWidget.__init__(self, parent)
+        qt.QWidget.__init__(self, parent)
         self._parent = parent
         self.ClientObj = ClientObj
         self.method_name = method_name
@@ -121,18 +122,18 @@ class MainFrameRes(QtGui.QWidget):
         #                                    "{background-color: #FFFFFF;}")
         #                                    #"{background-color: #E4E1E0;}")
         self.setObjectName("Frame_Res")
-        self.setStyleSheet("#Frame_Res {background-color: transparent;}")
+        self.setStyleSheet("#Frame_Res {background-color: %s;}"% get_system_rgb(self, ParameterWindow))
         #self.setStyleSheet("#Frame_Res {background-color: green;}")
 #                           "QWidget {border: 1px solid red;}")
 
-        self.timer = QtCore.QTimer(self)
-        self.connect(self.timer, QtCore.SIGNAL("timeout()"), self.show_bottom)
+        self.timer = qt.QTimer(self)
+        self.timer.timeout.connect(self.show_bottom)
         self.timer.start(100)
         self.valSignal.connect(self.show_bottom)
 
 
     def initUI(self):
-        #self.setSizePolicy(QtGui.QSizePolicy.Minimum,QtGui.QSizePolicy.Minimum)
+        #self.setSizePolicy(qt.QSizePolicy.Minimum,qt.QSizePolicy.Minimum)
         self.updateGeometry()
 
     def show_bottom(self):
@@ -201,22 +202,20 @@ class MainFrameRes(QtGui.QWidget):
             self.mytable.setHorizontalHeaderLabels(list_head)
             for line in range(len(table.body[0])):
                 for i in range(len(table.body[0][line][0])):
-                    tablewidgetitem = QtGui.QTableWidgetItem(
+                    tablewidgetitem = qt.QTableWidgetItem(
                         table.body[0][line][0][i])
-                    #tablewidgetitem.setTextAlignment(
-                    #    QtCore.Qt.Align | QtCore.Qt.AlignLeft)
                     self.mytable.setItem(line, i, tablewidgetitem)
             # set writeonly
-            self.mytable.setEditTriggers(QtGui.QAbstractItemView.NoEditTriggers)
+            self.mytable.setEditTriggers(qt.QAbstractItemView.NoEditTriggers)
 
             if table.onClick:
                 self.mytable.itemClicked.connect(self.row_activate(table))
 
             self.mytable.setColor()
-            minimum = QtGui.QSizePolicy.Minimum
+            minimum = qt.QSizePolicy.Minimum
             self.mytable.setSizePolicy(minimum, minimum)
             self.mytable.horizontalHeader().resizeSections(
-                QtGui.QHeaderView.ResizeMode.ResizeToContents)
+                qt.QHeaderView.ResizeToContents)
             self.work_layout._addWidget(self.mytable)
             self.ClientObj.app.processEvents()
             self.mytable.resizeRowsToContents()
@@ -278,9 +277,9 @@ class MainFrameRes(QtGui.QWidget):
         self.timer.stop()
 
     def add_offset_buttons(self, len_body, addAction, records):
-        offset_buttons = QtGui.QWidget()
-        layout = QtGui.QHBoxLayout(offset_buttons)
-        layout.setAlignment(QtCore.Qt.AlignLeft)
+        offset_buttons = qt.QWidget()
+        layout = qt.QHBoxLayout(offset_buttons)
+        layout.setAlignment(qt.Qt.AlignLeft)
 
         offset = self.ClientObj.param_objects[self.method_name]['offset']
         count_records = int(self.ClientObj.count_row_res_table)
@@ -298,23 +297,23 @@ class MainFrameRes(QtGui.QWidget):
                 last = False
 
 
-        begin_offset = QtGui.QPushButton(offset_buttons)
-        begin_offset.setIcon(QtGui.QIcon.fromTheme('go-first'))
+        begin_offset = qt.QPushButton(offset_buttons)
+        begin_offset.setIcon(get_icon('go-first'))
         begin_offset.setToolTip('First page')
         begin_offset.clicked.connect(self.disable_buttons)
         begin_offset.clicked.connect(self.call_method_with_offset(0, True))
-        begin_offset.setFixedWidth(30)
+        begin_offset.setFixedSize(30, 30)
         self.buttons.append(begin_offset)
 
         layout.addWidget(begin_offset)
 
-        minus_offset = QtGui.QPushButton(offset_buttons)
-        minus_offset.setIcon(QtGui.QIcon.fromTheme('go-previous'))
+        minus_offset = qt.QPushButton(offset_buttons)
+        minus_offset.setIcon(get_icon('go-previous'))
         minus_offset.setToolTip('Previous page')
         minus_offset.clicked.connect(self.disable_buttons)
         minus_offset.clicked.connect(self.call_method_with_offset(
             -count_records))
-        minus_offset.setFixedWidth(30)
+        minus_offset.setFixedSize(30, 30)
         layout.addWidget(minus_offset)
         self.buttons.append(minus_offset)
 
@@ -323,23 +322,23 @@ class MainFrameRes(QtGui.QWidget):
             begin_offset.setDisabled(True)
 
 
-        plus_offset = QtGui.QPushButton(offset_buttons)
-        plus_offset.setIcon(QtGui.QIcon.fromTheme('go-next'))
+        plus_offset = qt.QPushButton(offset_buttons)
+        plus_offset.setIcon(get_icon('go-next'))
         plus_offset.setToolTip('Next page')
         plus_offset.clicked.connect(self.disable_buttons)
         plus_offset.clicked.connect(self.call_method_with_offset(
             count_records))
-        plus_offset.setFixedWidth(30)
+        plus_offset.setFixedSize(30, 30)
         layout.addWidget(plus_offset)
         self.buttons.append(plus_offset)
 
-        last_offset = QtGui.QPushButton(offset_buttons)
-        last_offset.setIcon(QtGui.QIcon.fromTheme('go-last'))
+        last_offset = qt.QPushButton(offset_buttons)
+        last_offset.setIcon(get_icon('go-last'))
         last_offset.setToolTip('Last page')
         last_offset.clicked.connect(self.disable_buttons)
         last_offset.clicked.connect(self.call_method_with_offset(
             0, False, records - count_records))
-        last_offset.setFixedWidth(30)
+        last_offset.setFixedSize(30, 30)
         layout.addWidget(last_offset)
         self.buttons.append(last_offset)
 
@@ -837,7 +836,7 @@ class MainFrameRes(QtGui.QWidget):
         self.get_Frame(sid, pid, def_end_frame = end_frame)
 
     def add_Progress(self):
-        progressBar = QtGui.QProgressBar()
+        progressBar = qt.QProgressBar()
         progressBar.setMinimumHeight(progressBar.sizeHint().height())
         progressBar.setTextVisible(True)
         self.progress_list.append(progressBar)
@@ -1027,7 +1026,7 @@ class MainFrameRes(QtGui.QWidget):
         event.accept()
 
 
-class MessageDialog(QtGui.QWidget):
+class MessageDialog(qt.QWidget):
     # answer to the server question
     def __init__(self, parent, item, sid, pid, isPassword = False):
         super(MessageDialog, self).__init__()
@@ -1036,11 +1035,11 @@ class MessageDialog(QtGui.QWidget):
         self.sid = sid
         self.pid = pid
         self.setWindowTitle(self._parent.ClientObj._parent.windowTitle())
-        self.layout = QtGui.QGridLayout(self)
+        self.layout = qt.QGridLayout(self)
 
         self.label = LabelWordWrap(item.message, self)
 
-        self.pass_edit = QtGui.QLineEdit(self)
+        self.pass_edit = qt.QLineEdit(self)
         self.layout.addWidget(self.label,0,0)
         self.layout.addWidget(self.pass_edit,0,1)
 
@@ -1049,7 +1048,7 @@ class MessageDialog(QtGui.QWidget):
             self.pass_edit.setEchoMode(self.pass_edit.Password)
             if item.id == 2:
                 if hasattr(self,'pass_edit2'):
-                    self.pass_edit2 = QtGui.QLineEdit(self)
+                    self.pass_edit2 = qt.QLineEdit(self)
                     self.pass_edit2.setEchoMode(self.pass_edit2.Password)
 
                 self.layout.addWidget(LabelWordWrap(_('Repeat'), self), x, 0)
@@ -1059,8 +1058,8 @@ class MessageDialog(QtGui.QWidget):
                 if hasattr(self,'pass_edit2'):
                     self.pass_edit2.textChanged.connect(self.check_passwd)
 
-        self.send_button = QtGui.QPushButton(_('Send'), self)
-        self.send_button.setShortcut(QtGui.QKeySequence(QtCore.Qt.Key_Return))
+        self.send_button = qt.QPushButton(_('Send'), self)
+        self.send_button.setShortcut(qt.QKeySequence(qt.Qt.Key_Return))
         self.send_button.clicked.connect(self.send_password)
 
         self.layout.addWidget(self.send_button,x,1)
@@ -1071,8 +1070,7 @@ class MessageDialog(QtGui.QWidget):
                   parent.ClientObj._parent.geometry().y() + \
                   parent.ClientObj._parent.geometry().height() / 2 \
                   - self.sizeHint().height() / 2)
-        self.setWindowFlags (QtCore.Qt.WindowMinimizeButtonHint)
-#        self.setAttribute(QtCore.Qt.WA_ShowModal)
+        self.setWindowFlags (qt.Qt.WindowMinimizeButtonHint)
 
     def send_password(self):
         answer = self.pass_edit.text()
@@ -1106,7 +1104,7 @@ class MessageDialog(QtGui.QWidget):
             self.send_button.setEnabled(True)
 
 
-class ButtonDialog(QtGui.QWidget):
+class ButtonDialog(qt.QWidget):
     button_size = 144
 
     def __init__(self, parent, item, sid, pid):
@@ -1114,12 +1112,13 @@ class ButtonDialog(QtGui.QWidget):
         self._parent = parent
         self.sid = sid
         self.pid = pid
-        self.layout = QtGui.QHBoxLayout(self)
+        self.layout = qt.QHBoxLayout(self)
         self.layout.setContentsMargins(0, 0, 4, 0)
         self.header_label = None
 
-        minimum = QtGui.QSizePolicy.Fixed
+        minimum = qt.QSizePolicy.Fixed
         self.setSizePolicy(minimum, minimum)
+        self.setFixedHeight(32)
         self.init(item)
 
     def init(self, item):
@@ -1129,15 +1128,15 @@ class ButtonDialog(QtGui.QWidget):
         """
         Создать кнопку в диалоге
         """
-        button = QtGui.QPushButton(label, self)
+        button = qt.QPushButton(label, self)
         if type(shortcut) in (list, tuple):
-            action = QtGui.QAction(self)
-            action.setShortcuts(map(QtGui.QKeySequence,
+            action = qt.QAction(self)
+            action.setShortcuts(map(qt.QKeySequence,
                                     shortcut))
             action.triggered.connect(button.animateClick)
             button.addAction(action)
         elif shortcut:
-            button.setShortcut(QtGui.QKeySequence(shortcut))
+            button.setShortcut(qt.QKeySequence(shortcut))
         button.clicked.connect(self.send(answer, label))
         button.setFixedWidth(self.button_size)
         button.setFixedHeight(32)
@@ -1178,9 +1177,9 @@ class ConfirmDialog(ButtonDialog):
     def init(self, item):
         self._parent._parent.control_button.set_confirm_question(
             "<b>%s</b>" % item.message)
-        self.createButton(_("Yes"), "yes", [QtCore.Qt.Key_Enter,
-                                            QtCore.Qt.Key_Return])
-        self.createButton(_("No"), "no", QtCore.Qt.Key_Escape)
+        self.createButton(_("Yes"), "yes", [qt.Qt.Key_Enter,
+                                            qt.Qt.Key_Return])
+        self.createButton(_("No"), "no", qt.Qt.Key_Escape)
 
 
 class ChoiceDialog(ButtonDialog):
